import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:cometchat_uikit_shared/cometchat_uikit_shared.dart';

///[UIConstants] contains properties essential and limited to setting up the ui kit
class UIConstants {
  static const MethodChannel channel = MethodChannel('cometchat_uikit_shared');
  static const String packageName = "cometchat_uikit_shared";
}



///[MessageCategoryConstants] is a utility class that stores String constants of categories of messages
class MessageCategoryConstants {
  static const String message = CometChatMessageCategory.message;
  static const String action = CometChatMessageCategory.action;
  static const String call = CometChatMessageCategory.call;
  static const String custom = CometChatMessageCategory.custom;
}

///[MessageTypeConstants] is a utility class that stores String constants of types of messages
class MessageTypeConstants {
  static const String image = CometChatMessageType.image;
  static const String video = CometChatMessageType.video;
  static const String audio = CometChatMessageType.audio;
  static const String file = CometChatMessageType.file;
  static const String text = CometChatMessageType.text;
  static const String custom = CometChatMessageType.custom;
  static const String groupActions = "groupMember";
  static const String message = "message";
  static const String takePhoto = "takePhoto";
  static const String photoAndVideo = "photoAndVideo";
}

///[ReceiverTypeConstants] is a utility class that stores String constants of the types of [AppEntity] that can receive a [BaseMessage]
class ReceiverTypeConstants {
  static const String user = "user";
  static const String group = "group";
}

///[MessageOptionConstants] is a utility class that stores String constants of the actions permitted to execute on a particular [BaseMessage]
class MessageOptionConstants {
  static const String editMessage = "editMessage";
  static const String deleteMessage = "deleteMessage";
  static const String shareMessage = "shareMessage";
  static const String copyMessage = "copyMessage";
  static const String forwardMessage = "forwardMessage";
  // static const String replyMessage = "replyMessage";
  static const String replyInThreadMessage = "replyInThreadMessage";
  // static const String reactToMessage = "reactToMessage";
  // static const String translateMessage = "translateMessage";
  static const String messageInformation = "messageInformation";
  static const String sendMessagePrivately = "sendMessagePrivately";
  // static const String replyMessagePrivately = "replyMessagePrivately";
}

///[MetadataConstants] is a utility class that stores String constants to use in the [metadata] property of a [BaseMessage]
class MetadataConstants {
  static const String liveReaction = "live_reaction";
  // static const String replyMessage = "reply-message";
}

///[GroupOptionConstants] is a utility class that stores String constants of the options available in [CometChatDetails] if it is being rendered for a [Group]
class GroupOptionConstants {
  static const String leave = "leave";
  static const String delete = "delete";
  static const String viewMembers = "viewMembers";
  static const String addMembers = "addMembers";
  static const String bannedMembers = "bannedMembers";
  static const String voiceCall = "voiceCall";
  static const String videoCall = "videoCall";
}

///[GroupMemberOptionConstants] is a utility class that stores String constants of the actions permitted to a [GroupMember] to execute on a particular [Group]
class GroupMemberOptionConstants {
  static const String kick = "kick";
  static const String ban = "ban";
  static const String unban = "unban";
  static const String changeScope = "changeScope";
}

///[UserOptionConstants] is a utility class that stores String constants of the options available in [CometChatDetails] if it is being rendered for a [User]
class UserOptionConstants {
  static const String viewProfile = "viewProfile";
  static const String voiceCall = "voiceCall";
  static const String videoCall = "videoCall";
  static const String blockUser = "blockUser";
  static const String unblockUser = "unblockUser";
}

///[GroupTypeConstants] is a utility class that stores String constants of the types of [Group]
class GroupTypeConstants {
  static const String private = CometChatGroupType.private;
  static const String public = CometChatGroupType.public;
  static const String password = CometChatGroupType.password;
}

///[GroupMemberScope] is a utility class that stores String constants of scope of [GroupMember] with respect to a particular [Group]
class GroupMemberScope {
  static const String admin = CometChatMemberScope.admin;
  static const String moderator = CometChatMemberScope.moderator;
  static const String participant = CometChatMemberScope.participant;
  static const String owner = "owner";
}

///[UserStatusConstants] is a utility class that stores String constants of the online/offline status of an [User]
class UserStatusConstants {
  static const String online = CometChatUserStatus.online;
  static const String offline = CometChatUserStatus.offline;
}

///[ReceiptTypeConstants] is a utility class that stores String constants of the various stages of message delivery
class ReceiptTypeConstants {
  static const String delivered = CometChatReceiptType.delivered;
  static const String read = CometChatReceiptType.read;
}

///[DetailsTemplateConstants] is a utility class that stores String constants of the types of [CometChatDetailsTemplate]
class DetailsTemplateConstants {
  static const String primaryActions = "primaryActions";
  static const String secondaryActions = "secondaryActions";
  // static const String moreActions = "moreActions";
}

///[UITabNameConstants] is a utility class that stores String constants of the names of the tabs available for [CometChatUI]
class UITabNameConstants {
  static const userWithMessages = "userWithMessages";
  static const groupWithMessages = "groupWithMessages";
  static const conversationWithMessages = "conversationWithMessages";
}

///[ConversationOptionConstants] is a utility class that stores String constants of options available for [Conversation] items
class ConversationOptionConstants {
  static const delete = "delete";
}

///[CallStatusConstants] is a utility class that stores String constants of various stages of [Call]
class CallStatusConstants {
  static const initiated = "initiated";
  static const ongoing = "ongoing";
  static const rejected = "rejected";
  static const cancelled = "cancelled";
  static const busy = "busy";
  static const unanswered = "unanswered";
  static const ended = "ended";
}

///[OnError] defines the structure of error handler used by the components in the ui kit
typedef OnError = Function(Exception e);

typedef ComposerWidgetBuilder = Widget Function(
    BuildContext context, User? user, Group? group, Map<String, dynamic>? id);

typedef ComposerActionsBuilder = List<CometChatMessageComposerAction> Function(
    BuildContext context, User? user, Group? group, Map<String, dynamic>? id);


typedef UserGroupBuilder = Function(
    BuildContext context, User? user, Group? group);

///[LiveReactionConstants] is a utility class that stores constant values related to functioning of [TransientMessage]
class LiveReactionConstants {
  static const timeout = 1500;
}

///[CometChatStartConversationType] is a utility class that stores String constants of the types of [CometChatContacts]
class CometChatStartConversationType {
  static const String user = CometChatConversationType.user;
  static const String group = CometChatConversationType.group;
}

class CallTypeConstants {
  static const audioCall = "audio";
  static const videoCall = "video";
}